<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Sulje (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Pienennä</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Laajenna</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Kuittaa hälytys</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%1 % %Ln minuutista</numerusform>
            <numerusform>%1 % %Ln minuutista</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%1% of %Ln word(s)</source>
        <translation>
            <numerusform>%1 % %Ln sanasta</numerusform>
            <numerusform>%1 % %Ln sanasta</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln sana</numerusform>
            <numerusform>%Ln sanaa</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minuutti</numerusform>
            <numerusform>%Ln minuuttia</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0 %</translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Päivittäinen eteneminen</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Pisin putki</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Nykyinen putki</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>–</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n päivä</numerusform>
            <numerusform>%n päivää</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%1% of daily goal</source>
        <translation>%1 % päivittäisestä tavoitteesta</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Aseta kieli</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Nimetön %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (vain luku)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Tiedoston ”%1” tallentaminen epäonnistui.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Tallenna tiedosto nimellä</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Tiedoston ”%1” korvaaminen epäonnistui.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Nimeä tiedosto uudelleen</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Tiedoston ”%1” uudelleennimeäminen epäonnistui.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Ladataanko tiedosto uudelleen?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Ladataanko tiedosto ”%1” uudelleen levyltä?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Kaikki tallentamattomat muutokset menetetään.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Lataa uudelleen</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Nimetön %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Kysymys</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Pelkkänä tekstinä tallennettaessa menetetään kaikki muotoilu. Poistetaanko muotoilu?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Tiedosto muuttui</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Toinen ohjelma on muuttanut tiedostoa %1.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Haluatko ladata tiedoston uudelleen?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Lataa uudelleen</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Jätä huomiotta</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Tiedosto poistettu</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>Toinen ohjelma on poistanut tiedoston %1.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Haluatko tallentaa vai sulkea tiedoston?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Arkiston avaaminen epäonnistui.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Etsi:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Korvaa:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Aakkoskoolla ei ole merkitystä</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Vain kokonaiset sanat</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Säännölliset lausekkeet</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Etsi ylös</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Etsi alas</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Etsi</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Korvaa</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Korvaa k&amp;aikki</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Etsi</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Korvaa</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Korvataanko %n esiintymä?</numerusform>
            <numerusform>Korvataanko %n esiintymää?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Kysymys</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Fraasia ei löydy.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>OpenDocument-teksti</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>Litteä OpenDocument-XML</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Muotoiltu teksti</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Pelkkä teksti</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Kaikki tiedostot</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Kaikki tuetut tiedostot</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Lisää</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Tarkista oikeinkirjoitus…</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Ei ehdotuksia)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Avaa kuva</translation>
    </message>
    <message>
        <source>Images(%1)</source>
        <translation>Kuvat (%1)</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Valitse ohjelman kieli:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Järjestelmän kieli&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Huomaa</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Ole hyvä ja käynnistä ohjelma uudelleen, jotta kielen muutos tulee voimaan.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Arkiston avaaminen epäonnistui.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Yleisasetukset</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Tilastot</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Työkalupalkki</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Oikeinkirjoituksen tarkistus</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Valitse sanasto</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Arkiston avaaminen epäonnistui.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Arkisto ei sisällä käyttökelpoista sanastoa.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Kysymys</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Pikanäppäimet</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Yksi tai useampi päällekkäinen pikanäppäin. Haluatko jatkaa?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Sanasto ”%1” on jo olemassa. Haluatko korvata sen?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Päivittäinen tavoite</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ei tavoitetta</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Minuutteina:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Sanoina:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Muokkaaminen</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Keskitä aina pystysuunnassa</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Laatikkomainen lisäyskohdistin</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Tasoitetut fontit</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Kirjoituskoneäänet</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Älykkäät lainausmerkit:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Kokolainausmerkit</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Puolilainausmerkit</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Kohtaukset</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Erotin:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Tallennus</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Muista kohdistimen sijainti</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Sanamäärä</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Sivumäärä</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Kappalemäärä</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Merkkimäärä</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Merkkeinä:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Kappaleina:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Sanamäärän algoritmi</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Nollataanko tämän päivän eteneminen?</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Poistetaanko nykyinen sanakirja?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Kirjoita tavujärjestysmerkki (BOM) tekstitiedostoihin</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Oletusmuoto:</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Käyttöliittymä</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Näytä vierityspalkki aina</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Näytä yläpalkki aina</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Näytä alapalkki aina</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Nollaa tämä päivä</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Muista historia</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Näytä etenemisputket</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Vähin eteneminen voittoputkeen:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Tunnista sanojen rajat</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Jaa merkkimäärä kuudella</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Laske jokainen kirjain sanaksi</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Sivumäärän algoritmi</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Tyyli</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Vain kuvakkeet</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Vain teksti</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Teksti kuvakkeiden vieressä</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Teksti kuvakkeiden alla</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Tekstin sijainti:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Toiminnot</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Siirrä ylemmäs</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Siirrä alemmas</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Lisää erotin</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Komento</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Pikanäppäin</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Toiminto</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Tarkista oikeinkirjoitus kirjoitettaessa</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Ohita SUURAAKKOSIN kirjoitetut sanat</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Ohita sanat, joissa on numeroita</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Kieli</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Lisää</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Oma sanasto</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Ei tuettu RTF-tiedosto.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Tiedosto loppui yllättäen.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Siirrä kohtauksia ylemmäs</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Näytä tai piilota kohtausluettelo</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Näytä kohtausluettelo (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Piilota kohtausluettelo (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Suodatin</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Siirrä kohtauksia alemmas</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Muuta kohtausluettelon kokoa</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Oletus</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Hallitse istuntoja</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>&amp;Istunnot</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Uusi</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nimeä uudelleen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Siirry</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Uusi istunto</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Kopioi istunto</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Nimeä istunto uudelleen</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Kysymys</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Poistetaanko valittu istunto?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Istunnon nimi:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>Pyytämäsi istunnon nimi on jo käytössä.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Uusi…</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Hallitse…</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Tyhjennä</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Palauta oletusarvoon</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Pikanäppäin:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Korvataan lainausmerkkejä…</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Odota hetki</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Tarkista oikeinkirjoitus</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Lisää</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>Jätä &amp;huomiotta</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>&amp;Jätä kaikki huomiotta</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Muuta</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Muuta &amp;kaikki</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Ei sanastossa:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Vaihda muotoon:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Tarkistetaan oikeinkirjoitusta…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Odota hetki</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Jatketaanko tarkistamista tiedoston alusta?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Oikeinkirjoituksen tarkistus valmis.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Symbolit</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Viimeksi käytetyt symbolit</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Kaikki symbolit</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Tiedot</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nimi:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Lisää</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Lohkot</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Kirjoitusjärjestelmät</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Nimetön %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Nimi:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Ei kuvaa</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Toistettu</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Keskitetty</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Venytetty</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Skaalattu</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Suurennettu</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Peittävyys:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Sijainti:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Leveys:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Pyöristetyt kulmat tekstin taustassa</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Säde:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Sumenna tekstin tausta</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Tekstin taustan varjo</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Pystysiirtymä:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Reunukset</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Ikkuna:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Sivu:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Sisennä ensimmäinen rivi</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Yläpuolella:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Alapuolella:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Muokkaa teemaa</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Ikkunan tausta</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tyyppi:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Väri:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Kuva:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation> pikseliä</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vasemmalla</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Tekstin tausta</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Oikealla</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Teksti</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Fontti:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Kirjoitusvirheet:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Riviväli</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Yksinkertainen</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1,5-kertainen</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Kaksinkertainen</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Suhteellinen</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Korkeus:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Kappaleväli</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Sarkainleveys:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Uusi teema</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Teemat</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Oletusteemat</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Karvaat taivaat</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Lumous</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Pehmeänsininen</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Vanhanaikainen</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Avaruusunelma</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Vakoojaleikit</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Rauha</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Kirjoituspöytä</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Uusi</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Omat teemat</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Tuo</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Vie</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Kysymys</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Poistetaanko teema %1?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Teemat (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Tuo teema</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Vie teema</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; – %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Kysymys</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Poistetaanko ajastin?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Sanoja:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Sivuja:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Kappaleita:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Merkkejä:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Aseta viive</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Aseta aika</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Viive:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Aika:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Hälytys</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tyyppi:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Lisätieto:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Ei ajastimia käynnissä</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Ajastimet</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Uusi</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Viimeisimmät</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Kysymys</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Perutaanko ajastimien muokkaus?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 – %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Ladataan teemoja</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Ladataan ääniä</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Nimetön</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Avaa tiedosto</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>Tietoja FocusWriterista</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Yksinkertainen koko näytön tekstinkäsittelyohjelma</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008–%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Julkaistu &lt;a href=%1&gt;GPL 3&lt;/a&gt;-lisenssillä</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Käyttää &lt;a href=%1&gt;Oxygen&lt;/a&gt;-kuvaketeemaa</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Käytetty &lt;a href=%1&gt;LGPL 3&lt;/a&gt;-lisenssin mukaisesti</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Merkkejä: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Sivuja: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Kappaleita: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Sanoja: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Avataan %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Nimetön %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Luettele kaikki asiakirjat</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Siirry seuraavaan asiakirjaan</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Siirry edelliseen asiakirjaan</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Siirry ensimmäiseen asiakirjaan</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Siirry viimeiseen asiakirjaan</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Siirry asiakirjaan %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Ladataan asetuksia</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Varavälimuistiin ei voida kirjoittaa.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Varoitus</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter ei sulkeutunut oikein.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Palautetaanko tilanne varavälimuistista?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Joitain tiedostoja ei saatu avattua.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Osa tiedostoista avattiin vain luku -tilassa.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>%1 on uudempi kuin välimuistin versio.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Korvataanko uudempi tiedosto?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Tallennetaanko muutokset?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Tallennetaanko muutokset tiedostoon ”%1” ennen sulkemista?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Muutoksesi häviävät, jollet tallenna niitä.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Kirjoituskoneäänien lataaminen epäonnistui.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Tiedosto</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Uusi</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Avaa…</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Lataa uu&amp;delleen</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Tallenna</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Tallenna &amp;nimellä…</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>Ni&amp;meä uudelleen…</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Tallenna &amp;kaikki</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Hallitse istuntoja</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Uusi istunto</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Tul&amp;osta…</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Sivuasetukset...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Sulje</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Lopeta</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Muokkaa</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Peru</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Tee uudelleen</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>L&amp;eikkaa</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopioi</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Liitä</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Liitä &amp;muotoilematta</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Valitse k&amp;aikki</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>&amp;Valitse kohtaus</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>M&amp;uotoilu</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>Otsikko</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Otsikko &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Otsikko &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Otsikko &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Otsikko &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Otsikko &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Otsikko &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Tavallinen</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>Li&amp;havointi</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>Ku&amp;rsivointi</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>All&amp;eviivaus</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>Yl&amp;iviivaus</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>&amp;Yläindeksi</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>&amp;Alaindeksi</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>Tasaa &amp;vasemmalle</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>Tasaa &amp;keskelle</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Tasaa &amp;oikealle</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>&amp;Tasaa molemmat reunat</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>&amp;Ulonna</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>&amp;Sisennä</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Vase&amp;mmalta oikealle</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Oikea&amp;lta vasemmalle</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>T&amp;yökalut</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Etsi…</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Etsi &amp;seuraava</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Etsi edelli&amp;nen</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>&amp;Korvaa…</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>Älykkäät &amp;lainausmerkit</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Päivitä &amp;asiakirja</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Päivitä dokumentin älykkäät lainausmerkit</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Päivitä &amp;valinta</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Päivitä valinnan älykkäät lainausmerkit</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>&amp;Oikeinkirjoitus…</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Ase&amp;ta kieli…</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>&amp;Ajastimet…</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>S&amp;ymbolit…</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Päivittäinen eteneminen</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Asetukset</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Näytä &amp;työkalupalkki</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Näytä &amp;valikkokuvakkeet</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>K&amp;ohdistettu teksti</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>Koko &amp;näyttö</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>P&amp;ienennä</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>T&amp;eemat…</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Asetukset…</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Kohdistus pois päältä</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Kohdista yksi rivi</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Kohdista kolme riviä</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Kappale</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Kohdista kappale</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ohje</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Ohjelman &amp;kieli…</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Joidenkin tiedostojen tiedostomuotoja ei tueta; niiden avaaminen epäonnistui.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Ei kohdistusta</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>&amp;Yksi rivi</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>Kolme &amp;riviä</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Tietoja</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Tietoja &amp;Qt:sta</translation>
    </message>
</context>
</TS>
